@@ -22,11 +22,11 @@ Virani - PCAP retrieval for a FPC setup writing to PCAP files.
 
 =head1 VERSION
 
-Version 1.0.0
+Version 1.0.1
 
 =cut
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.0.1';
 
 =head1 SYNOPSIS
 
@@ -170,7 +170,8 @@ sub new {
 	# real in basic values
 	my @real_in = (
 		'apikey',           'default_set',       'cache',   'padding',
-		'default_max_time', 'verbose_to_syslog', 'verbose', 'auth_by_IP_only'
+		'default_max_time', 'verbose_to_syslog', 'verbose', 'auth_by_IP_only',
+		'type'
 	);
 	for my $key (@real_in) {
 		if ( defined( $opts{$key} ) ) {
@@ -214,6 +215,12 @@ Does a quick and dumb conversion of a BPF filter to tshark.
     src host $host -> ip.src == $host
     not src host $host -> ip.src != $host
 
+    dst $host -> ip.dst == $host
+    not host $host -> ip.dst != $host
+
+    src src $host -> ip.src == $host
+    not src $host -> ip.src != $host
+
 =cut
 
 sub bpf2tshark {
@@ -370,7 +377,7 @@ sub bpf2tshark {
 		elsif (defined( $previous[0] )
 			&& defined( $previous[1] )
 			&& $previous[0] eq 'src'
-			&& $previous[1] eq 'port' )
+			&& $previous[1] eq 'host' )
 		{
 			push( @tshark_args, 'ip.src', $equality, $item );
 			$not      = 0;
@@ -381,7 +388,7 @@ sub bpf2tshark {
 		elsif (defined( $previous[0] )
 			&& defined( $previous[1] )
 			&& $previous[0] eq 'dst'
-			&& $previous[1] eq 'port' )
+			&& $previous[1] eq 'host' )
 		{
 			push( @tshark_args, 'ip.dst', $equality, $item );
 			$not      = 0;
@@ -396,12 +403,26 @@ sub bpf2tshark {
 		}
 
 		# add host $host
-		elsif ( defined( $previous[0] ) && !defined( $previous[1] ) && $previous[0] eq 'port' ) {
+		elsif ( defined( $previous[0] ) && !defined( $previous[1] ) && $previous[0] eq 'host' ) {
 			push( @tshark_args, 'ip.addr', $equality, $item );
 			$not      = 0;
 			@previous = ();
 		}
 
+		# add src $host
+		elsif ( defined( $previous[0] ) && !defined( $previous[1] ) && $previous[0] eq 'src' ) {
+			push( @tshark_args, 'ip.src', $equality, $item );
+			$not      = 0;
+			@previous = ();
+		}
+
+		# add dst $host
+		elsif ( defined( $previous[0] ) && !defined( $previous[1] ) && $previous[0] eq 'dst' ) {
+			push( @tshark_args, 'ip.dst', $equality, $item );
+			$not      = 0;
+			@previous = ();
+		}
+
 		# if anything else is found, skip it
 		else {
 			$not      = 0;
@@ -409,7 +430,7 @@ sub bpf2tshark {
 		}
 	} ## end foreach my $item (@bpf_split)
 
-	return join(' ', @tshark_args);
+	return join( ' ', @tshark_args );
 } ## end sub bpf2tshark
 
 =head2 filter_clean
@@ -902,9 +923,8 @@ sub get_pcap_local {
 	# set the padding
 	my $start = $opts{start} - $opts{padding};
 	my $end   = $opts{end} + $opts{padding};
-	$self->verbose( 'info',
-		'Padded Start: ' . $opts{start}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{start}->epoch );
-	$self->verbose( 'info', 'Padded End: ' . $opts{end}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{end}->epoch );
+	$self->verbose( 'info', 'Padded Start: ' . $start->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $start->epoch );
+	$self->verbose( 'info', 'Padded End: ' . $end->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $end->epoch );
 
 	# get the set
 	my $set_path = $self->get_set_path( $opts{set} );
@@ -963,6 +983,7 @@ sub get_pcap_local {
 	if ( $opts{type} eq 'bpf2tshark' ) {
 		$tshark_filter = $self->bpf2tshark( $opts{filter} );
 		$to_return->{filter_translated} = $tshark_filter;
+		$self->verbose( 'info', 'Translated Filter ' . $tshark_filter );
 	}
 
 	# the merge command
